//**************************************************************************
//
//
//                       National Institute Of Standards and Technology
//                                     DTS Version 1.0
//
//                                    Notation Interface
//**************************************************************************

function Notation()
{
   var tests = new Array (core0001NT(), core0002NT(), core0003NT(),core0004NT(),
                core0005NT());

   return tests;
}

//------------------------ test case core-0001NT ------------------------
//
// Testing feature - The nodeName (from the Node interface) contains the name
//                   of the notation.
//
// Testing approach - Retrieve the notation named "notation1" and access its 
//                    name by invoking the nodeName attribute from the Node 
//                    interface.
//
// Semantic Requirements: 1
//
// Last modification date - May 3, 1999
//
// Written by: Carmelo Montanez
//----------------------------------------------------------------------------

 function core0001NT()
 {
   var computedValue = "";
   var expectedValue = "notation1"
   var testNode = "";

    results = new testResults("Core0001NT");

    results.derscription = "The \"nodeName\" attribute (from the Node "+
                           "interface) contains the name of the notation.";
//
// Retrieve the targeted data. 
//
    testNode = getNotation("notation1");
    computedValue = testNode.nodeName;
//
// Write out results
//
    results.expected = expectedValue;
    results.actual = computedValue;

    return results;
}

//------------------------ End test case core-0001NT --------------------------
//
//--------------------------- test case core-0002NT ---------------------------
//
// Testing feature - The "publicId" attribute of a Notation node contains the
//                   public identifier associated with the notation, if one was
//                   specified. 
//
// Testing approach - Retrieve the notation named "notation1" and access its 
//                    "publicId" attribute.  It should be set to 
//                    "notation1File"
//
// Semantic Requirements: 2 
//
// Last modification date - May 3, 1999
//
// Written by: Carmelo Montanez
//----------------------------------------------------------------------------

 function core0002NT()
 {
   var computedValue = "";
   var expectedValue = "notation1File"; 
   var testNode = "";

    results = new testResults("Core0002NT");

    results.description = "The \"publicId\" attribute contains the public "+
                          "identifier associated with this notation.";
//
// Retrieve the targeted data and access its "publicId" attribute.
//
    testNode = getNotation("notation1");
    computedValue = testNode.publicId;
//
// Write out results
//
    results.expected = expectedValue;
    results.actual = computedValue;

    return results;
}

//------------------------ End test case core-0002NT --------------------------
//
//--------------------------- test case core-0003NT ---------------------------
//
// Testing feature - If no public identifier was specified for the notation,
//                   the "publicId" attribute is null.
//
// Testing approach - Retrieve the notation named "notation1" and access its
//                    "publicId" attribute.  Since no public identifier
//                    was specified for this notation, the "publicId" 
//                    attribute should be null.
//
// Semantic Requirements: 3 
//
// Last modification date - April 30, 1999
//
// Written by: Carmelo Montanez
//----------------------------------------------------------------------------

 function core0003NT()
 {
   var computedValue = "";
   var expectedValue = null;
   var testNode = "";

    results = new testResults("Core0003NT");

    results.description = "The \"publicId\" attribute is null if no public "+
                          "identifier was specified for this notation.";
//
// Retrieve the targeted data and access its "publicId" attribute.
//
    testNode = getNotation("notation2");
    computedValue = testNode.publicId;
//
// Write out results
//
    results.expected = expectedValue;
    results.actual = computedValue;

    return results;
}

//------------------------ End test case core-0003NT --------------------------
//
//--------------------------- test case core-0004NT ---------------------------
//
// Testing feature - The "systemId" attribute of a Notation node contains the
//                   system identifier associated with the notation, if one was
//                   specified.
//
// Testing approach - Retrieve the notation named "notation2" and access its
//                    "systemId" attribute.  It should be set to
//                    "Notation2File".
//
// Semantic Requirements: 4 
//
// Last modification date - May 3, 1999
//
// Written by: Carmelo Montanez
//----------------------------------------------------------------------------

 function core0004NT()
 {
   var computedValue = "";
   var expectedValue = "notation2File";
   var testNode = "";

    results = new testResults("Core0004NT");

    results.description = "The \"systemId\" attribute contains the system "+
                          "identifier associated with this notation.";
//
// Retrieve the targeted data and access its "systemId" attribute.
//
    testNode = getNotation("notation2");
    computedValue = testNode.systemId;
//
// Write out results
//
    results.expected = expectedValue;
    results.actual = computedValue;

    return results;
}

//------------------------ End test case core-0004NT --------------------------
//
//--------------------------- test case core-0005NT ---------------------------
//
// Testing feature - If no system identifier was specified for the notation,
//                   the "systemId" attribute is null.
//
// Testing approach - Retrieve the notation named "notation1" and access its
//                    "systemId" attribute.  Since no system identifier
//                    was specified for this notation, the "systemId"
//                    attribute should be null.
//
// Semantic Requirements: 5 
//
// Last modification date - May 3, 1999
//
// Written by: Carmelo Montanez
//----------------------------------------------------------------------------

 function core0005NT()
 {
   var computedValue = "";
   var expectedValue = null;
   var testNode = "";

    results = new testResults("Core0005NT");

    results.description = "The \"systemId\" attribute is null if no system "+
                          "system identifier was specified for this notation.";
//
// Retrieve the targeted data and access its "systemId" attribute.
//
    testNode = getNotation("notation1");
    computedValue = testNode.systemId;
//
// Write out results
//
    results.expected = expectedValue;
    results.actual = computedValue;

    return results;
}

//------------------------ End test case core-0005NT --------------------------
